from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
import os
import time
import pickle  # zum Speichern und Laden von Cookies

# --- Browser-Konfiguration für Brave (sichtbarer Modus) ---
chrome_options = Options()
chrome_options.binary_location = '/usr/bin/brave-browser'  # Pfad zu Brave
chrome_options.add_argument("--no-sandbox")
chrome_options.add_argument("--disable-dev-shm-usage")
chrome_options.add_argument("--disable-setuid-sandbox")
chrome_options.add_argument("--disable-extensions")
chrome_options.add_argument("--disable-features=RendererCodeIntegrity")
chrome_options.add_argument("--remote-debugging-port=9222")
chrome_options.add_argument("--disable-gpu")
chrome_options.add_argument("--disable-features=VizDisplayCompositor")
# Headless-Modus nicht aktivieren

# --- ChromeDriver konfigurieren ---
driver_path = '/usr/local/bin/chromedriver'  # Pfad zu ChromeDriver
service = Service(driver_path)

driver = webdriver.Chrome(service=service, options=chrome_options)
wait = WebDriverWait(driver, 30)

# --- Manuelles Login und Cookie-Speicherung ---
driver.get("https://account.komoot.com/signin")
print("Bitte melde dich manuell bei Komoot an und drücke dann Enter im Terminal.")
input("Wenn du eingeloggt bist, drücke Enter...")
# Wechsel zur Upload-Seite, damit die Session aktiv ist:
driver.get("https://www.komoot.com/de-de/upload")
print("Verifiziere, ob du eingeloggt bist...")
# Cookies speichern (optional, für zukünftige Durchläufe)
cookies = driver.get_cookies()
with open("komoot_cookies.pkl", "wb") as cookie_file:
    pickle.dump(cookies, cookie_file)
print("Cookies wurden gespeichert.")

# --- GPX-Upload starten ---
gpx_folder = '/pfad/zu/den/aktivitaeten'

for root, dirs, files in os.walk(gpx_folder):
    for file in files:
        if file.lower().endswith('.gpx'):
            file_path = os.path.join(root, file)
            print(f"Uploading {file_path}...")

            # Gehe zur Upload-Seite
            driver.get("https://www.komoot.com/de-de/upload")
            
            # Direkt mit dem Datei-Input interagieren (um das native Fenster zu umgehen)
            file_input = wait.until(EC.presence_of_element_located((By.XPATH, '//input[@type="file"]')))
            driver.execute_script("arguments[0].style.display = 'block';", file_input)
            file_input.send_keys(file_path)
            
            # Wähle den Radio-Button "Als gemachte Tour importieren"
            gemachte_radio = wait.until(EC.element_to_be_clickable(
                (By.XPATH, "//div[contains(@class, 'radio-box') and .//p[contains(text(),'Als gemachte Tour importieren')]]")
            ))
            gemachte_radio.click()
            
            # Klicke auf den "Weiter"-Button, um zum nächsten Schritt zu gelangen
            weiter_button = wait.until(EC.element_to_be_clickable(
                (By.XPATH, "//button[contains(text(),'Weiter')]")
            ))
            weiter_button.click()
            
            # Nun erscheint der Bereich, in dem die aktuelle Toursichtbarkeit angezeigt wird.
            # Klicke auf den "Ändern"-Button im entsprechenden Container (letzter Button in einem div, das "Sichtbar:" enthält)
            change_visibility_button = wait.until(EC.element_to_be_clickable(
                (By.XPATH, "(//div[contains(., 'Sichtbar:')]//button[contains(text(),'Ändern')])[last()]")
            ))
            change_visibility_button.click()
            
            # Nach dem Klick öffnet sich das Overlay.
            # Wähle hier den untersten radio-box-Container, der den Text "Alle" enthält.
            alle_option = wait.until(EC.element_to_be_clickable(
                (By.XPATH, "(//div[contains(@class, 'radio-box') and .//p[contains(text(), 'Alle')]])[last()]")
            ))
            alle_option.click()
            
            # Abschließend klicke auf den finalen Button "Aufzeichnung importieren"
            final_import_button = wait.until(EC.element_to_be_clickable(
                (By.XPATH, "//button[contains(text(),'Aufzeichnung importieren')]")
            ))
            final_import_button.click()
            
            # Kurze Pause, damit der Upload-Prozess abgeschlossen werden kann
            time.sleep(5)

driver.quit()
